@@ -36,9 +36,9 @@ void ags_line_member_editor_entry_init(AgsLineMemberEditorEntry *line_member_edi
 GType
 ags_line_member_editor_entry_get_type(void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__static = 0;
 
-  if(g_once_init_enter (&g_define_type_id__volatile)){
+  if(g_once_init_enter(&g_define_type_id__static)){
     GType ags_type_line_member_editor_entry = 0;
 
     static const GTypeInfo ags_line_member_editor_entry_info = {
@@ -57,10 +57,10 @@ ags_line_member_editor_entry_get_type(void)
 							       "AgsLineMemberEditorEntry", &ags_line_member_editor_entry_info,
 							       0);
 
-    g_once_init_leave(&g_define_type_id__volatile, ags_type_line_member_editor_entry);
+    g_once_init_leave(&g_define_type_id__static, ags_type_line_member_editor_entry);
   }
 
-  return g_define_type_id__volatile;
+  return(g_define_type_id__static);
 }
 
 void
